summaryrefslogtreecommitdiff
path: root/src/compiler/scala/tools/nsc/typechecker/Typers.scala
diff options
context:
space:
mode:
authorJakob Odersky <jakob@odersky.com>2016-04-25 15:00:09 -0700
committerJakob Odersky <jakob@odersky.com>2016-07-15 01:20:32 -0700
commit543d719dce062e6ea99c21c7320def711af1cf9e (patch)
treedb6230e5667241dc007788563510c3b390368d6c /src/compiler/scala/tools/nsc/typechecker/Typers.scala
parent4e564efb04e508ccc0f479cf1a25331501927d88 (diff)
downloadscala-543d719dce062e6ea99c21c7320def711af1cf9e.tar.gz
scala-543d719dce062e6ea99c21c7320def711af1cf9e.tar.bz2
scala-543d719dce062e6ea99c21c7320def711af1cf9e.zip
Retain javadoc comments in scaladoc
* Hook into java parser to generate doc comments * Generate empty trees for java implementation bodies
Diffstat (limited to 'src/compiler/scala/tools/nsc/typechecker/Typers.scala')
-rw-r--r--src/compiler/scala/tools/nsc/typechecker/Typers.scala7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/compiler/scala/tools/nsc/typechecker/Typers.scala b/src/compiler/scala/tools/nsc/typechecker/Typers.scala
index 9fa3564b2b..ba104fb7a6 100644
--- a/src/compiler/scala/tools/nsc/typechecker/Typers.scala
+++ b/src/compiler/scala/tools/nsc/typechecker/Typers.scala
@@ -2247,9 +2247,10 @@ trait Typers extends Adaptations with Tags with TypersTracking with PatternTyper
transformedOrTyped(ddef.rhs, EXPRmode, tpt1.tpe)
}
- if (meth.isClassConstructor && !isPastTyper && !meth.owner.isSubClass(AnyValClass)) {
- // At this point in AnyVal there is no supercall, which will blow up
- // in computeParamAliases; there's nothing to be computed for Anyval anyway.
+ if (meth.isClassConstructor && !isPastTyper && !meth.owner.isSubClass(AnyValClass) && !meth.isJava) {
+ // There are no supercalls for AnyVal or constructors from Java sources, which
+ // would blow up in computeParamAliases; there's nothing to be computed for them
+ // anyway.
if (meth.isPrimaryConstructor)
computeParamAliases(meth.owner, vparamss1, rhs1)
else